@@ -9,9 +9,7 @@ def init_logger(verbose):
     """Initialize logger based on `verbose`."""
     level = logging.DEBUG if verbose >= 1 else logging.INFO
 
-    logging.basicConfig(
-        level=level, format='%(message)s'
-    )
+    logging.basicConfig(level=level, format="%(message)s")
 
 
 def main():
@@ -21,14 +19,20 @@ def main():
         args = cli.parse_args(user_config)
         init_logger(args.verbose)
 
-        if args.command == 'start':
+        if args.command == "start":
             script.start(args)
-        elif args.command == 'done':
+        elif args.command == "done":
             script.done(args)
+    except KeyboardInterrupt:
+        logging.info("\nCanceled by user")
+        sys.exit(0)
     except script.ScriptError as exc:
         logging.error(exc)
         sys.exit(1)
+    except Exception as exc:
+        logging.error("Unexpected script error: %s", exc)
+        sys.exit(2)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
